@@ -2,10 +2,10 @@ package API::Instagram;
 
 # ABSTRACT: Object Oriented Interface for the Instagram REST and Search APIs
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 use Moo;
-with 'MooX::Singleton';
+# with 'MooX::Singleton';
 
 use Carp;
 use strict;
@@ -41,6 +41,10 @@ has _access_token_url => ( is => 'ro', default => sub { 'https://api.instagram.c
 
 has _debug => ( is => 'rw', lazy => 1 );
 
+my $instance;
+sub BUILD { $instance = shift }
+
+sub instance { $instance //= shift->new(@_) }
 
 sub get_auth_url { 
 	my $self = shift;
@@ -210,7 +214,7 @@ __END__
 
 API::Instagram - Object Oriented Interface for the Instagram REST and Search APIs
 
-=for Pod::Coverage client_id client_secret grant_type no_cache redirect_uri response_type scope
+=for Pod::Coverage client_id client_secret grant_type no_cache redirect_uri response_type scope BUILD
 
 =for HTML <a href="https://travis-ci.org/gabrielmad/API-Instagram"><img src="https://travis-ci.org/gabrielmad/API-Instagram.svg?branch=build%2Fmaster"></a>
 
@@ -218,13 +222,13 @@ API::Instagram - Object Oriented Interface for the Instagram REST and Search API
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
 	use API::Instagram;
 
-	my $instagram = API::Instagram->instance({
+	my $instagram = API::Instagram->new({
 			client_id     => $client_id,
 			client_secret => $client_secret,
 			redirect_uri  => 'http://localhost',
@@ -256,7 +260,7 @@ Get the AUTH URL to authenticate.
 
 	use API::Instagram;
 
-	my $instagram = API::Instagram->instance({
+	my $instagram = API::Instagram->new({
 			client_id     => 'xxxxxxxxxx',
 			client_secret => 'xxxxxxxxxx',
 			redirect_uri  => 'http://localhost',
@@ -287,9 +291,9 @@ authenticated user credentials.
 
 =head1 METHODS
 
-=head2 instance
+=head2 new
 
-	my $instagram = API::Instagram->instance({
+	my $instagram = API::Instagram->new({
 			client_id     => $client_id,
 			client_secret => $client_secret,
 			redirect_uri  => 'http://localhost',
@@ -311,6 +315,23 @@ C<response_type> and C<granty_type> do no vary. See L<http://instagram.com/devel
 By default, L<API::Instagram> caches created objects to avoid duplications. You can disable
 this feature setting a true value to C<no_chace> parameter.
 
+=head2 instance
+
+	my $instagram = API::Instagram->instance;
+	print $instagram->user->full_name;
+
+	or
+
+	my $instagram = API::Instagram->instance({
+			client_id     => $client_id,
+			client_secret => $client_secret,
+			redirect_uri  => 'http://localhost',
+	});
+
+Returns the singleton instance of L<API::Instagram>.
+
+Note: if no instance was created before, creates a new L<API::Instagram> object initialized with arguments provided and then returns it.
+
 =head2 get_auth_url
 
 	my $auth_url = $instagram->get_auth_url;
